<?php
/**
 * Plugin Name: Easy Floating Call Now Button
 * Description: Adds a customizable floating call button with text and visual effects.
 * Version: 1.0
 * Author: ssik
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

if (!defined('ABSPATH')) {
    exit; // Prevent direct access
}

// Include settings
require_once plugin_dir_path(__FILE__) . 'includes/settings.php';

// Set default settings on activation
register_activation_hook(__FILE__, 'efcnb_set_default_settings');
function efcnb_set_default_settings() {
    $default_settings = [
        'enabled' => '1',
        'phone' => '',
        'button_text' => 'Call Us',
        'background_color' => '#86ec6a',
        'inner_color' => '#ffffff',
        'text_color' => '#ffffff',
        'text_bg_color' => '#000000',
        'display' => 'all',
        'pages' => []
    ];
    $current_settings = get_option('efcnb_settings', []);
    update_option('efcnb_settings', array_merge($default_settings, $current_settings));
}

// Enqueue styles if conditions are met
add_action('wp_enqueue_scripts', 'efcnb_enqueue_assets');
function efcnb_enqueue_assets() {
    $options = get_option('efcnb_settings');

    if (!isset($options['enabled']) || $options['enabled'] !== '1') {
        return;
    }

    if (($options['display'] === 'mobile' && !wp_is_mobile()) ||
        ($options['display'] === 'desktop' && wp_is_mobile())) {
        return;
    }

    $allowed_pages = $options['pages'] ?? [];
    if (!efcnb_is_allowed_page($allowed_pages)) {
        return;
    }

    $style_path = plugin_dir_path(__FILE__) . 'assets/efcnb-style.css';
    $version = file_exists($style_path) ? filemtime($style_path) : '1.0';
    wp_enqueue_style('efcnb-style', plugin_dir_url(__FILE__) . 'assets/efcnb-style.css', [], $version);
}

// Render the button
add_action('wp_footer', 'efcnb_render_button');
function efcnb_render_button() {
    $options = get_option('efcnb_settings');
    if (!isset($options['enabled']) || $options['enabled'] !== '1') {
        return;
    }

    if (($options['display'] === 'mobile' && !wp_is_mobile()) ||
        ($options['display'] === 'desktop' && wp_is_mobile())) {
        return;
    }

    $allowed_pages = $options['pages'] ?? [];
    if (!efcnb_is_allowed_page($allowed_pages)) {
        return;
    }

    // Get and sanitize values
    $phone = $options['phone'] ?? '';
    $button_text = $options['button_text'] ?? 'Call Us';
    $background_color = $options['background_color'] ?? '#86ec6a';
    $inner_color = $options['inner_color'] ?? '#ffffff';
    $text_color = $options['text_color'] ?? '#ffffff';
    $text_bg_color = $options['text_bg_color'] ?? '#000000';

    $text_bg_color_rgba = efcnb_convert_to_rgba($text_bg_color, 0.5);
    $text_bg_color_rgba_escaped = esc_attr($text_bg_color_rgba);
    $background_color_escaped = esc_attr($background_color);
    $inner_color_escaped = esc_attr($inner_color);
    $text_color_escaped = esc_attr($text_color);

    $size = '56px';

    // Output with escaping at the point of output
    echo '<div class="efcnb-wrapper">
        <div class="efcnb-content">
            <span class="efcnb-text" style="' . esc_attr("--text-bg-color: {$text_bg_color_rgba_escaped}; --text-color: {$text_color_escaped};") . '">' . esc_html($button_text) . '</span>
            <a href="tel:' . esc_attr($phone) . '" class="efcnb-button" style="' . esc_attr("--svg-color: {$background_color_escaped}; --svg-inner-color: {$inner_color_escaped}; --svg-size: {$size};") . '">
                <svg class="efcnb-icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 56 56">
                    <path class="outer" d="M 27.9999 51.9062 C 41.0546 51.9062 51.9063 41.0547 51.9063 28.0000 C 51.9063 14.9219 41.0312 4.0938 27.9765 4.0938 C 14.8983 4.0938 4.0937 14.9219 4.0937 28.0000 C 4.0937 41.0547 14.9218 51.9062 27.9999 51.9062 Z" fill="currentColor"/>
                    <path class="inner" d="M 21.8827 33.8360 C 16.0702 28.0469 12.3671 20.6640 16.7499 16.2813 C 17.0077 16.0234 17.2890 15.7656 17.5468 15.5078 C 18.8827 14.2422 20.1718 14.3125 21.3202 15.9297 L 24.3671 20.2656 C 25.3983 21.7656 25.1405 22.6094 24.0390 23.7813 L 23.0780 24.8360 C 22.7265 25.1640 22.8671 25.6094 23.0312 25.8906 C 23.4765 26.7344 24.7421 28.2344 26.1014 29.5938 C 27.5077 31.0000 28.9374 32.1953 29.8280 32.6875 C 30.1562 32.875 30.6249 32.9219 30.9296 32.6406 L 31.9374 31.6797 C 33.0624 30.5781 33.9765 30.2969 35.4296 31.3281 C 37.4452 32.7578 38.6640 33.6016 39.8593 34.4219 C 41.3358 35.5000 41.6874 36.8360 40.1874 38.1953 C 39.9296 38.4531 39.6952 38.7344 39.4374 38.9922 C 35.0546 43.3516 27.6952 39.6484 21.8827 33.8360 Z" fill="var(--svg-inner-color)"/>
                </svg>
            </a>
        </div>
    </div>';
}

function efcnb_convert_to_rgba($color, $alpha) {
    $color = trim($color);

    if (strpos($color, 'rgb(') !== false) {
        preg_match('/rgb\(\s*(\d+),\s*(\d+),\s*(\d+)\s*\)/', $color, $matches);
        if (count($matches) === 4) {
            return "rgba({$matches[1]}, {$matches[2]}, {$matches[3]}, {$alpha})";
        }
    }

    if (strpos($color, '#') === 0) {
        $hex = substr($color, 1);
        if (strlen($hex) === 3) {
            $hex = $hex[0].$hex[0].$hex[1].$hex[1].$hex[2].$hex[2];
        }
        if (strlen($hex) === 6) {
            $r = hexdec(substr($hex, 0, 2));
            $g = hexdec(substr($hex, 2, 2));
            $b = hexdec(substr($hex, 4, 2));
            return "rgba({$r}, {$g}, {$b}, {$alpha})";
        }
    }

    return "rgba(0, 0, 0, {$alpha})";
}

function efcnb_is_allowed_page($allowed_pages) {
    if (empty($allowed_pages)) return true;
    if (is_front_page() && in_array('home', $allowed_pages)) return true;
    if (is_single() && in_array('posts', $allowed_pages)) return true;
    if (is_page() && in_array('pages', $allowed_pages)) return true;
    if (is_category() && in_array('categories', $allowed_pages)) return true;
    return false;
}